@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0308';
+our $VERSION = '0.0309';
 
 use Moo;
 use strictures 2;
@@ -179,8 +179,7 @@ sub chord_key {
         defined $self->key_note     ? $self->key_note     : 'KeyNote',
         defined $self->key          ? $self->key          : 'Key',
         defined $self->key_function ? $self->key_function : 'KeyFunction',
-        defined $self->key_roman    ? $self->key_roman    : 'KeyRoman',
-    ;
+        defined $self->key_roman    ? $self->key_roman    : 'KeyRoman';
     return $self->_querydb($query);
 }
 
@@ -197,8 +196,7 @@ sub pivot_chord_keys {
         defined $self->key_note      ? $self->key_note      : 'KeyNote',
         defined $self->key           ? $self->key           : 'Key',
         defined $self->key_function  ? $self->key_function  : 'KeyFunction',
-        defined $self->key_roman     ? $self->key_roman     : 'KeyRoman',
-    ;
+        defined $self->key_roman     ? $self->key_roman     : 'KeyRoman';
     return $self->_querydb($query);
 }
 
@@ -209,8 +207,7 @@ sub roman_key {
         defined $self->mode       ? $self->mode       : 'Mode',
         defined $self->mode_roman ? $self->mode_roman : 'ModeRoman',
         defined $self->key        ? $self->key        : 'Key',
-        defined $self->key_roman  ? $self->key_roman  : 'KeyRoman',
-    ;
+        defined $self->key_roman  ? $self->key_roman  : 'KeyRoman';
     return $self->_querydb($query);
 }
 
@@ -244,7 +241,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0308
+version 0.0309
 
 =head1 SYNOPSIS
 
@@ -256,7 +253,7 @@ version 0.0308
     chord        => 'maj',
     key_function => 'dominant',
   );
-  my $q = $m->chord_key;
+  my $results = $m->chord_key;
   # [['chord_key','d','maj','g','ionian','dominant','r_V'],
   #  ['chord_key','d','maj','g','lydian','dominant','r_V']]
 
@@ -267,7 +264,7 @@ version 0.0308
     mode_note    => 'c',
     key_function => 'subdominant',
   );
-  $q = $m->pivot_chord_keys;
+  $results = $m->pivot_chord_keys;
   # [['pivot_chord_keys','g','maj','c','ionian','dominant','d','dorian','subdominant','r_IV'],
   #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','ionian','subdominant','r_IV'],
   #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','mixolydian','subdominant','r_IV'],
@@ -294,26 +291,50 @@ resulting in all possible truths.
 
 =head2 chord_note
 
+C<c>, C<df>, C<d>, C<ef>, C<e>, C<f>, C<gf>, C<g>, C<af>, C<a>, C<bf>, or C<b>
+
+* Sharps are not used - only flats.
+
 =head2 chord
 
+  C<maj>, C<min>, or C<dim>
+
 =head2 mode_note
 
+C<c>, C<df>, C<d>, C<ef>, C<e>, C<f>, C<gf>, C<g>, C<af>, C<a>, C<bf>, or C<b>
+
 =head2 mode
 
+C<ionian>, C<dorian>, C<phrygian>, C<lydian>, C<mixolydian>, C<aeolian>, or C<locrian>
+
 =head2 mode_function
 
+C<tonic>, C<supertonic>, C<mediant>, C<subdominant>, C<dominant>, C<submediant>, C<leading_tone>, or C<subtonic>
+
 =head2 mode_roman
 
+C<r_I>, C<r_ii>, C<r_iii>, C<r_IV>, C<r_V>, C<r_vi>, or C<r_vii>
+
 =head2 key_note
 
+C<c>, C<df>, C<d>, C<ef>, C<e>, C<f>, C<gf>, C<g>, C<af>, C<a>, C<bf>, or C<b>
+
 =head2 key
 
+C<ionian>, C<dorian>, C<phrygian>, C<lydian>, C<mixolydian>, C<aeolian>, or C<locrian>
+
 =head2 key_function
 
+C<tonic>, C<supertonic>, C<mediant>, C<subdominant>, C<dominant>, C<submediant>, C<leading_tone>, or C<subtonic>
+
 =head2 key_roman
 
+C<r_I>, C<r_ii>, C<r_iii>, C<r_IV>, C<r_V>, C<r_vi>, or C<r_vii>
+
 =head2 verbose
 
+Default: C<0>
+
 =head1 METHODS
 
 =head2 new
@@ -324,13 +345,13 @@ Create a new C<Music::ModalFunction> object.
 
 =head2 chord_key
 
-  $q = $m->chord_key;
+  $results = $m->chord_key;
 
 Ask the database a question about what chords are in what keys.
 
-Arguments:
+Positional arguments:
 
-  chord_key(ChordNote, Chord, KeyNote, Key, KeyFunction, KeyRoman)
+  ChordNote, Chord, KeyNote, Key, KeyFunction, KeyRoman
 
 Here, B<ChordNote> and B<Chord> together are the named chord defined
 within the context of the B<KeyNote> and B<Key>. The chord's function
@@ -344,13 +365,13 @@ unbound variable is used.
 
 =head2 pivot_chord_keys
 
-  $q = $m->pivot_chord_keys;
+  $results = $m->pivot_chord_keys;
 
 Ask the database a question about what chords share common keys.
 
-Arguments:
+Positional arguments:
 
-  pivot_chord_keys(ChordNote, Chord, ModeNote, Mode, ModeFunction, ModeRoman, KeyNote, Key, KeyFunction, KeyRoman)
+  ChordNote, Chord, ModeNote, Mode, ModeFunction, ModeRoman, KeyNote, Key, KeyFunction, KeyRoman
 
 Here, B<ChordNote> and B<Chord> together are the named chord defined
 within the context of the B<ModeNote> and B<Mode>. The chord's
@@ -367,14 +388,14 @@ unbound variable is used.
 
 =head2 roman_key
 
-  $q = $m->roman_key;
+  $results = $m->roman_key;
 
 Ask the database a question about what Roman numeral functional chords
 share common keys.
 
-Arguments:
+Positional arguments:
 
-  roman_key(Mode, ModeRoman, Key, KeyRoman)
+  Mode, ModeRoman, Key, KeyRoman
 
 If defined, argument values will be bound to a variable. Otherwise an
 unbound variable is used.
